SQLAlchemy 0.3 Documentation - module sqlalchemy.engine.url

# SQLAlchemy 0.3 Documentation

Multiple Pages | One Page
Version: 0.3.7 Last Updated: 04/30/07 00:08:52

### module sqlalchemy.engine.url

### Module Functions

def make_url(name_or_url)

Given a string or unicode instance, produce a new URL instance.

The given string is parsed according to the rfc1738 spec. If an existing URL object is passed, just returns the object.

### class URL(object)

Represent the components of a URL used to connect to a database.

This object is suitable to be passed directly to a `create_engine()` call. The fields of the URL are parsed from a string by the `module-level make_url()` function. the string format of the URL is an RFC-1738-style string.

Attributes on URL include:

drivername
  The name of the database backend. this name will correspond to a module in sqlalchemy/databases
username
  The user name for the connection.
password
  database password.
host
  The name of the host.
port
  The port number.
database
  The database.
query
  A dictionary containing key/value pairs representing the URL's query string.

def __init__(self, drivername, username=None, password=None, host=None, port=None, database=None, query=None)
def get_dialect(self)

Return the SQLAlchemy database dialect class corresponding to this URL's driver name.

def translate_connect_args(self, names)

Translate this URL's attributes into a dictionary of connection arguments.

Given a list of argument names corresponding to the URL attributes (host, database, username, password, port), will assemble the attribute values of this URL into the dictionary using the given names.

back to section top